LIBRARY
EXPORTS
caldat
compare_map DATA
decode_base64
decode_quoted_printable
free_zone_directory
ical_bt
icalarray_append
icalarray_element_at
icalarray_free
icalarray_new
icalarray_remove_element_at
icalarray_sort
icalattach_get_data
icalattach_get_is_url
icalattach_get_url
icalattach_new_from_data
icalattach_new_from_url
icalattach_ref
icalattach_unref
icalcompiter_deref
icalcompiter_next
icalcompiter_null DATA
icalcompiter_prior
icalcomponent_add_children
icalcomponent_add_component
icalcomponent_add_property
icalcomponent_as_ical_string
icalcomponent_as_ical_string_r
icalcomponent_begin_component
icalcomponent_check_restrictions
icalcomponent_convert_errors
icalcomponent_count_components
icalcomponent_count_errors
icalcomponent_count_properties
icalcomponent_end_component
icalcomponent_foreach_recurrence
icalcomponent_foreach_tzid
icalcomponent_free
icalcomponent_get_comment
icalcomponent_get_current_component
icalcomponent_get_current_property
icalcomponent_get_description
icalcomponent_get_dtend
icalcomponent_get_dtstamp
icalcomponent_get_dtstart
icalcomponent_get_due
icalcomponent_get_duration
icalcomponent_get_first_component
icalcomponent_get_first_property
icalcomponent_get_first_real_component
icalcomponent_get_inner
icalcomponent_get_location
icalcomponent_get_method
icalcomponent_get_next_component
icalcomponent_get_next_property
icalcomponent_get_parent
icalcomponent_get_recurrenceid
icalcomponent_get_relcalid
icalcomponent_get_sequence
icalcomponent_get_span
icalcomponent_get_status
icalcomponent_get_summary
icalcomponent_get_timezone
icalcomponent_get_uid
icalcomponent_is_valid
icalcomponent_isa
icalcomponent_isa_component
icalcomponent_kind_is_valid
icalcomponent_kind_to_string
icalcomponent_merge_component
icalcomponent_new
icalcomponent_new_clone
icalcomponent_new_from_string
icalcomponent_new_vagenda
icalcomponent_new_valarm
icalcomponent_new_vcalendar
icalcomponent_new_vevent
icalcomponent_new_vfreebusy
icalcomponent_new_vjournal
icalcomponent_new_vquery
icalcomponent_new_vreply
icalcomponent_new_vtimezone
icalcomponent_new_vtodo
icalcomponent_new_x
icalcomponent_new_xdaylight
icalcomponent_new_xstandard
icalcomponent_remove_component
icalcomponent_remove_property
icalcomponent_set_comment
icalcomponent_set_description
icalcomponent_set_dtend
icalcomponent_set_dtstamp
icalcomponent_set_dtstart
icalcomponent_set_due
icalcomponent_set_duration
icalcomponent_set_location
icalcomponent_set_method
icalcomponent_set_parent
icalcomponent_set_recurrenceid
icalcomponent_set_relcalid
icalcomponent_set_sequence
icalcomponent_set_status
icalcomponent_set_summary
icalcomponent_set_uid
icalcomponent_string_to_kind
icalcomponent_strip_errors
icalcomponent_vanew
icaldurationtype_as_ical_string
icaldurationtype_as_ical_string_r
icaldurationtype_as_int
icaldurationtype_bad_duration
icaldurationtype_from_int
icaldurationtype_from_string
icaldurationtype_is_bad_duration
icaldurationtype_is_null_duration
icaldurationtype_null_duration
icalenum_num_to_reqstat
icalenum_reqstat_code
icalenum_reqstat_code_r
icalenum_reqstat_desc
icalenum_reqstat_major
icalenum_reqstat_minor
icalerrno_return
icalerror_clear_errno
icalerror_crash_here
icalerror_error_from_string
icalerror_get_error_state
icalerror_perror
icalerror_restore
icalerror_set_errno
icalerror_set_error_state
icalerror_stop_here
icalerror_strerror
icalerror_supress
icallangbind_access_array
icallangbind_free_array
icallangbind_get_first_component
icallangbind_get_first_parameter
icallangbind_get_first_property
icallangbind_get_next_component
icallangbind_get_next_parameter
icallangbind_get_next_property
icallangbind_new_array
icallangbind_property_eval_string
icallangbind_property_eval_string_r
icallangbind_quote_as_ical
icallangbind_quote_as_ical_r
icallangbind_string_to_open_flag
icalmemory_add_tmp_buffer
icalmemory_append_char
icalmemory_append_string
icalmemory_free_buffer
icalmemory_free_ring
icalmemory_free_ring_byval
icalmemory_free_tmp_buffer
icalmemory_new_buffer
icalmemory_resize_buffer
icalmemory_strdup
icalmemory_tmp_buffer
icalmemory_tmp_copy
icalmime_attachment_add_line
icalmime_attachment_end_part
icalmime_attachment_free_part
icalmime_attachment_new_part
icalmime_make_part
icalmime_parse
icalmime_test
icalmime_text_add_line
icalmime_text_end_part
icalmime_text_end_part_r
icalmime_text_free_part
icalmime_text_new_part
icalmime_textcalendar_end_part
icalparameter_as_ical_string
icalparameter_as_ical_string_r
icalparameter_enum_to_string
icalparameter_free
icalparameter_get_actionparam
icalparameter_get_altrep
icalparameter_get_charset
icalparameter_get_cn
icalparameter_get_cutype
icalparameter_get_delegatedfrom
icalparameter_get_delegatedto
icalparameter_get_dir
icalparameter_get_enable
icalparameter_get_encoding
icalparameter_get_fbtype
icalparameter_get_fmttype
icalparameter_get_id
icalparameter_get_language
icalparameter_get_latency
icalparameter_get_local
icalparameter_get_localize
icalparameter_get_member
icalparameter_get_options
icalparameter_get_parent
icalparameter_get_partstat
icalparameter_get_range
icalparameter_get_related
icalparameter_get_reltype
icalparameter_get_role
icalparameter_get_rsvp
icalparameter_get_sentby
icalparameter_get_tzid
icalparameter_get_value
icalparameter_get_x
icalparameter_get_xliccomparetype
icalparameter_get_xlicerrortype
icalparameter_get_xname
icalparameter_get_xvalue
icalparameter_isa
icalparameter_isa_parameter
icalparameter_kind_to_string
icalparameter_new
icalparameter_new_actionparam
icalparameter_new_altrep
icalparameter_new_charset
icalparameter_new_clone
icalparameter_new_cn
icalparameter_new_cutype
icalparameter_new_delegatedfrom
icalparameter_new_delegatedto
icalparameter_new_dir
icalparameter_new_enable
icalparameter_new_encoding
icalparameter_new_fbtype
icalparameter_new_fmttype
icalparameter_new_from_string
icalparameter_new_from_value_string
icalparameter_new_id
icalparameter_new_impl
icalparameter_new_language
icalparameter_new_latency
icalparameter_new_local
icalparameter_new_localize
icalparameter_new_member
icalparameter_new_options
icalparameter_new_partstat
icalparameter_new_range
icalparameter_new_related
icalparameter_new_reltype
icalparameter_new_role
icalparameter_new_rsvp
icalparameter_new_sentby
icalparameter_new_tzid
icalparameter_new_value
icalparameter_new_x
icalparameter_new_xliccomparetype
icalparameter_new_xlicerrortype
icalparameter_set_actionparam
icalparameter_set_altrep
icalparameter_set_charset
icalparameter_set_cn
icalparameter_set_cutype
icalparameter_set_delegatedfrom
icalparameter_set_delegatedto
icalparameter_set_dir
icalparameter_set_enable
icalparameter_set_encoding
icalparameter_set_fbtype
icalparameter_set_fmttype
icalparameter_set_id
icalparameter_set_language
icalparameter_set_latency
icalparameter_set_local
icalparameter_set_localize
icalparameter_set_member
icalparameter_set_options
icalparameter_set_parent
icalparameter_set_partstat
icalparameter_set_range
icalparameter_set_related
icalparameter_set_reltype
icalparameter_set_role
icalparameter_set_rsvp
icalparameter_set_sentby
icalparameter_set_tzid
icalparameter_set_value
icalparameter_set_x
icalparameter_set_xliccomparetype
icalparameter_set_xlicerrortype
icalparameter_set_xname
icalparameter_set_xvalue
icalparameter_string_to_enum
icalparameter_string_to_kind
icalparameter_value_to_value_kind
icalparser_add_line
icalparser_clean
icalparser_free
icalparser_get_line
icalparser_get_state
icalparser_get_value
icalparser_new
icalparser_parse
icalparser_parse_string
icalparser_set_gen_data
icalparser_string_line_generator
icalperiodtype_as_ical_string
icalperiodtype_as_ical_string_r
icalperiodtype_from_string
icalperiodtype_is_null_period
icalperiodtype_is_valid_period
icalperiodtype_null_period
icalproperty_add_parameter
icalproperty_add_parameters
icalproperty_as_ical_string
icalproperty_as_ical_string_r
icalproperty_count_parameters
icalproperty_enum_belongs_to_property
icalproperty_enum_to_string
icalproperty_enum_to_string_r
icalproperty_free
icalproperty_get_action
icalproperty_get_allowconflict
icalproperty_get_attach
icalproperty_get_attendee
icalproperty_get_calid
icalproperty_get_calmaster
icalproperty_get_calscale
icalproperty_get_capversion
icalproperty_get_carid
icalproperty_get_carlevel
icalproperty_get_categories
icalproperty_get_class
icalproperty_get_cmd
icalproperty_get_comment
icalproperty_get_completed
icalproperty_get_components
icalproperty_get_contact
icalproperty_get_created
icalproperty_get_csid
icalproperty_get_datemax
icalproperty_get_datemin
icalproperty_get_decreed
icalproperty_get_defaultcharset
icalproperty_get_defaultlocale
icalproperty_get_defaulttzid
icalproperty_get_defaultvcars
icalproperty_get_deny
icalproperty_get_description
icalproperty_get_dtend
icalproperty_get_dtstamp
icalproperty_get_dtstart
icalproperty_get_due
icalproperty_get_duration
icalproperty_get_exdate
icalproperty_get_expand
icalproperty_get_exrule
icalproperty_get_first_parameter
icalproperty_get_freebusy
icalproperty_get_geo
icalproperty_get_grant
icalproperty_get_itipversion
icalproperty_get_lastmodified
icalproperty_get_location
icalproperty_get_maxcomponentsize
icalproperty_get_maxdate
icalproperty_get_maxresults
icalproperty_get_maxresultssize
icalproperty_get_method
icalproperty_get_mindate
icalproperty_get_multipart
icalproperty_get_name
icalproperty_get_next_parameter
icalproperty_get_organizer
icalproperty_get_owner
icalproperty_get_parameter_as_string
icalproperty_get_parameter_as_string_r
icalproperty_get_parent
icalproperty_get_percentcomplete
icalproperty_get_permission
icalproperty_get_priority
icalproperty_get_prodid
icalproperty_get_property_name
icalproperty_get_property_name_r
icalproperty_get_query
icalproperty_get_queryid
icalproperty_get_querylevel
icalproperty_get_queryname
icalproperty_get_rdate
icalproperty_get_recuraccepted
icalproperty_get_recurexpand
icalproperty_get_recurlimit
icalproperty_get_recurrenceid
icalproperty_get_relatedto
icalproperty_get_relcalid
icalproperty_get_repeat
icalproperty_get_requeststatus
icalproperty_get_resources
icalproperty_get_restriction
icalproperty_get_rrule
icalproperty_get_scope
icalproperty_get_sequence
icalproperty_get_status
icalproperty_get_storesexpanded
icalproperty_get_summary
icalproperty_get_target
icalproperty_get_transp
icalproperty_get_trigger
icalproperty_get_tzid
icalproperty_get_tzname
icalproperty_get_tzoffsetfrom
icalproperty_get_tzoffsetto
icalproperty_get_tzurl
icalproperty_get_uid
icalproperty_get_url
icalproperty_get_value
icalproperty_get_value_as_string
icalproperty_get_value_as_string_r
icalproperty_get_version
icalproperty_get_x
icalproperty_get_x_name
icalproperty_get_xlicclass
icalproperty_get_xlicclustercount
icalproperty_get_xlicerror
icalproperty_get_xlicmimecharset
icalproperty_get_xlicmimecid
icalproperty_get_xlicmimecontenttype
icalproperty_get_xlicmimeencoding
icalproperty_get_xlicmimefilename
icalproperty_get_xlicmimeoptinfo
icalproperty_isa
icalproperty_isa_property
icalproperty_kind_and_string_to_enum
icalproperty_kind_is_valid
icalproperty_kind_to_string
icalproperty_kind_to_value_kind
icalproperty_method_to_string
icalproperty_new
icalproperty_new_action
icalproperty_new_allowconflict
icalproperty_new_attach
icalproperty_new_attendee
icalproperty_new_calid
icalproperty_new_calmaster
icalproperty_new_calscale
icalproperty_new_capversion
icalproperty_new_carid
icalproperty_new_carlevel
icalproperty_new_categories
icalproperty_new_class
icalproperty_new_clone
icalproperty_new_cmd
icalproperty_new_comment
icalproperty_new_completed
icalproperty_new_components
icalproperty_new_contact
icalproperty_new_created
icalproperty_new_csid
icalproperty_new_datemax
icalproperty_new_datemin
icalproperty_new_decreed
icalproperty_new_defaultcharset
icalproperty_new_defaultlocale
icalproperty_new_defaulttzid
icalproperty_new_defaultvcars
icalproperty_new_deny
icalproperty_new_description
icalproperty_new_dtend
icalproperty_new_dtstamp
icalproperty_new_dtstart
icalproperty_new_due
icalproperty_new_duration
icalproperty_new_exdate
icalproperty_new_expand
icalproperty_new_exrule
icalproperty_new_freebusy
icalproperty_new_from_string
icalproperty_new_geo
icalproperty_new_grant
icalproperty_new_impl
icalproperty_new_itipversion
icalproperty_new_lastmodified
icalproperty_new_location
icalproperty_new_maxcomponentsize
icalproperty_new_maxdate
icalproperty_new_maxresults
icalproperty_new_maxresultssize
icalproperty_new_method
icalproperty_new_mindate
icalproperty_new_multipart
icalproperty_new_name
icalproperty_new_organizer
icalproperty_new_owner
icalproperty_new_percentcomplete
icalproperty_new_permission
icalproperty_new_priority
icalproperty_new_prodid
icalproperty_new_query
icalproperty_new_queryid
icalproperty_new_querylevel
icalproperty_new_queryname
icalproperty_new_rdate
icalproperty_new_recuraccepted
icalproperty_new_recurexpand
icalproperty_new_recurlimit
icalproperty_new_recurrenceid
icalproperty_new_relatedto
icalproperty_new_relcalid
icalproperty_new_repeat
icalproperty_new_requeststatus
icalproperty_new_resources
icalproperty_new_restriction
icalproperty_new_rrule
icalproperty_new_scope
icalproperty_new_sequence
icalproperty_new_status
icalproperty_new_storesexpanded
icalproperty_new_summary
icalproperty_new_target
icalproperty_new_transp
icalproperty_new_trigger
icalproperty_new_tzid
icalproperty_new_tzname
icalproperty_new_tzoffsetfrom
icalproperty_new_tzoffsetto
icalproperty_new_tzurl
icalproperty_new_uid
icalproperty_new_url
icalproperty_new_version
icalproperty_new_x
icalproperty_new_xlicclass
icalproperty_new_xlicclustercount
icalproperty_new_xlicerror
icalproperty_new_xlicmimecharset
icalproperty_new_xlicmimecid
icalproperty_new_xlicmimecontenttype
icalproperty_new_xlicmimeencoding
icalproperty_new_xlicmimefilename
icalproperty_new_xlicmimeoptinfo
icalproperty_recurrence_is_excluded
icalproperty_remove_parameter
icalproperty_remove_parameter_by_kind
icalproperty_remove_parameter_by_name
icalproperty_remove_parameter_by_ref
icalproperty_set_action
icalproperty_set_allowconflict
icalproperty_set_attach
icalproperty_set_attendee
icalproperty_set_calid
icalproperty_set_calmaster
icalproperty_set_calscale
icalproperty_set_capversion
icalproperty_set_carid
icalproperty_set_carlevel
icalproperty_set_categories
icalproperty_set_class
icalproperty_set_cmd
icalproperty_set_comment
icalproperty_set_completed
icalproperty_set_components
icalproperty_set_contact
icalproperty_set_created
icalproperty_set_csid
icalproperty_set_datemax
icalproperty_set_datemin
icalproperty_set_decreed
icalproperty_set_defaultcharset
icalproperty_set_defaultlocale
icalproperty_set_defaulttzid
icalproperty_set_defaultvcars
icalproperty_set_deny
icalproperty_set_description
icalproperty_set_dtend
icalproperty_set_dtstamp
icalproperty_set_dtstart
icalproperty_set_due
icalproperty_set_duration
icalproperty_set_exdate
icalproperty_set_expand
icalproperty_set_exrule
icalproperty_set_freebusy
icalproperty_set_geo
icalproperty_set_grant
icalproperty_set_itipversion
icalproperty_set_lastmodified
icalproperty_set_location
icalproperty_set_maxcomponentsize
icalproperty_set_maxdate
icalproperty_set_maxresults
icalproperty_set_maxresultssize
icalproperty_set_method
icalproperty_set_mindate
icalproperty_set_multipart
icalproperty_set_name
icalproperty_set_organizer
icalproperty_set_owner
icalproperty_set_parameter
icalproperty_set_parameter_from_string
icalproperty_set_parent
icalproperty_set_percentcomplete
icalproperty_set_permission
icalproperty_set_priority
icalproperty_set_prodid
icalproperty_set_query
icalproperty_set_queryid
icalproperty_set_querylevel
icalproperty_set_queryname
icalproperty_set_rdate
icalproperty_set_recuraccepted
icalproperty_set_recurexpand
icalproperty_set_recurlimit
icalproperty_set_recurrenceid
icalproperty_set_relatedto
icalproperty_set_relcalid
icalproperty_set_repeat
icalproperty_set_requeststatus
icalproperty_set_resources
icalproperty_set_restriction
icalproperty_set_rrule
icalproperty_set_scope
icalproperty_set_sequence
icalproperty_set_status
icalproperty_set_storesexpanded
icalproperty_set_summary
icalproperty_set_target
icalproperty_set_transp
icalproperty_set_trigger
icalproperty_set_tzid
icalproperty_set_tzname
icalproperty_set_tzoffsetfrom
icalproperty_set_tzoffsetto
icalproperty_set_tzurl
icalproperty_set_uid
icalproperty_set_url
icalproperty_set_value
icalproperty_set_value_from_string
icalproperty_set_version
icalproperty_set_x
icalproperty_set_x_name
icalproperty_set_xlicclass
icalproperty_set_xlicclustercount
icalproperty_set_xlicerror
icalproperty_set_xlicmimecharset
icalproperty_set_xlicmimecid
icalproperty_set_xlicmimecontenttype
icalproperty_set_xlicmimeencoding
icalproperty_set_xlicmimefilename
icalproperty_set_xlicmimeoptinfo
icalproperty_status_to_string
icalproperty_string_to_enum
icalproperty_string_to_kind
icalproperty_string_to_method
icalproperty_string_to_status
icalproperty_value_kind_to_kind
icalproperty_vanew_action
icalproperty_vanew_allowconflict
icalproperty_vanew_attach
icalproperty_vanew_attendee
icalproperty_vanew_calid
icalproperty_vanew_calmaster
icalproperty_vanew_calscale
icalproperty_vanew_capversion
icalproperty_vanew_carid
icalproperty_vanew_carlevel
icalproperty_vanew_categories
icalproperty_vanew_class
icalproperty_vanew_cmd
icalproperty_vanew_comment
icalproperty_vanew_completed
icalproperty_vanew_components
icalproperty_vanew_contact
icalproperty_vanew_created
icalproperty_vanew_csid
icalproperty_vanew_datemax
icalproperty_vanew_datemin
icalproperty_vanew_decreed
icalproperty_vanew_defaultcharset
icalproperty_vanew_defaultlocale
icalproperty_vanew_defaulttzid
icalproperty_vanew_defaultvcars
icalproperty_vanew_deny
icalproperty_vanew_description
icalproperty_vanew_dtend
icalproperty_vanew_dtstamp
icalproperty_vanew_dtstart
icalproperty_vanew_due
icalproperty_vanew_duration
icalproperty_vanew_exdate
icalproperty_vanew_expand
icalproperty_vanew_exrule
icalproperty_vanew_freebusy
icalproperty_vanew_geo
icalproperty_vanew_grant
icalproperty_vanew_itipversion
icalproperty_vanew_lastmodified
icalproperty_vanew_location
icalproperty_vanew_maxcomponentsize
icalproperty_vanew_maxdate
icalproperty_vanew_maxresults
icalproperty_vanew_maxresultssize
icalproperty_vanew_method
icalproperty_vanew_mindate
icalproperty_vanew_multipart
icalproperty_vanew_name
icalproperty_vanew_organizer
icalproperty_vanew_owner
icalproperty_vanew_percentcomplete
icalproperty_vanew_permission
icalproperty_vanew_priority
icalproperty_vanew_prodid
icalproperty_vanew_query
icalproperty_vanew_queryid
icalproperty_vanew_querylevel
icalproperty_vanew_queryname
icalproperty_vanew_rdate
icalproperty_vanew_recuraccepted
icalproperty_vanew_recurexpand
icalproperty_vanew_recurlimit
icalproperty_vanew_recurrenceid
icalproperty_vanew_relatedto
icalproperty_vanew_relcalid
icalproperty_vanew_repeat
icalproperty_vanew_requeststatus
icalproperty_vanew_resources
icalproperty_vanew_restriction
icalproperty_vanew_rrule
icalproperty_vanew_scope
icalproperty_vanew_sequence
icalproperty_vanew_status
icalproperty_vanew_storesexpanded
icalproperty_vanew_summary
icalproperty_vanew_target
icalproperty_vanew_transp
icalproperty_vanew_trigger
icalproperty_vanew_tzid
icalproperty_vanew_tzname
icalproperty_vanew_tzoffsetfrom
icalproperty_vanew_tzoffsetto
icalproperty_vanew_tzurl
icalproperty_vanew_uid
icalproperty_vanew_url
icalproperty_vanew_version
icalproperty_vanew_x
icalproperty_vanew_xlicclass
icalproperty_vanew_xlicclustercount
icalproperty_vanew_xlicerror
icalproperty_vanew_xlicmimecharset
icalproperty_vanew_xlicmimecid
icalproperty_vanew_xlicmimecontenttype
icalproperty_vanew_xlicmimeencoding
icalproperty_vanew_xlicmimefilename
icalproperty_vanew_xlicmimeoptinfo
icalrecur_add_bydayrules
icalrecur_add_byrules
icalrecur_check_rulepart
icalrecur_clause_name_and_value
icalrecur_expand_recurrence
icalrecur_first_clause
icalrecur_freq_to_string
icalrecur_iterator_free
icalrecur_iterator_new
icalrecur_iterator_next
icalrecur_iterator_sizeof_byarray
icalrecur_next_clause
icalrecur_string_to_freq
icalrecur_string_to_weekday
icalrecur_weekday_to_string
icalrecurrencetype_as_string
icalrecurrencetype_as_string_r
icalrecurrencetype_clear
icalrecurrencetype_day_day_of_week
icalrecurrencetype_day_position
icalrecurrencetype_from_string
icalreqstattype_as_string
icalreqstattype_as_string_r
icalreqstattype_from_string
icalrestriction_check
icalrestriction_check_component
icalrestriction_compare
icalrestriction_may_be_comp_need_process
icalrestriction_may_be_draft_final_canceled
icalrestriction_may_be_tent_conf
icalrestriction_may_be_tent_conf_cancel
icalrestriction_must_be_cancel_if_present
icalrestriction_must_be_canceled_no_attendee
icalrestriction_must_be_email
icalrestriction_must_be_recurring
icalrestriction_must_have_duration
icalrestriction_must_have_repeat
icalrestriction_must_if_tz_ref
icalrestriction_no_dtend
icalrestriction_no_duration
icaltime_add
icaltime_adjust
icaltime_as_ical_string
icaltime_as_ical_string_r
icaltime_as_timet
icaltime_as_timet_with_zone
icaltime_compare
icaltime_compare_date_only
icaltime_compare_date_only_tz
icaltime_convert_to_zone
icaltime_current_time_with_zone
icaltime_day_of_week
icaltime_day_of_year
icaltime_days_in_month
icaltime_from_day_of_year
icaltime_from_string
icaltime_from_timet
icaltime_from_timet_with_zone
icaltime_get_timezone
icaltime_get_tzid
icaltime_is_date
icaltime_is_leap_year
icaltime_is_null_time
icaltime_is_utc
icaltime_is_valid_time
icaltime_normalize
icaltime_null_date
icaltime_null_time
icaltime_set_timezone
icaltime_span_contains
icaltime_span_new
icaltime_span_overlaps
icaltime_start_doy_of_week
icaltime_start_doy_week
icaltime_subtract
icaltime_today
icaltime_week_number
icaltimezone_array_append_from_vtimezone
icaltimezone_array_free
icaltimezone_array_new
icaltimezone_convert_time
icaltimezone_copy
icaltimezone_dump_changes
icaltimezone_free
icaltimezone_free_builtin_timezones
icaltimezone_get_builtin_timezone
icaltimezone_get_builtin_timezone_from_offset
icaltimezone_get_builtin_timezone_from_tzid
icaltimezone_get_builtin_timezones
icaltimezone_get_component
icaltimezone_get_display_name
icaltimezone_get_latitude
icaltimezone_get_location
icaltimezone_get_longitude
icaltimezone_get_tzid
icaltimezone_get_tznames
icaltimezone_get_utc_offset
icaltimezone_get_utc_offset_of_utc_time
icaltimezone_get_utc_timezone
icaltimezone_new
icaltimezone_release_zone_tab
icaltimezone_set_component
icaltimezone_set_tzid_prefix
icaltriggertype_from_int
icaltriggertype_from_string
icaltriggertype_is_bad_trigger
icaltriggertype_is_null_trigger
icaltzutil_fetch_timezone
icaltzutil_get_zone_directory
icalvalue_as_ical_string
icalvalue_as_ical_string_r
icalvalue_compare
icalvalue_decode_ical_string
icalvalue_encode_ical_string
icalvalue_free
icalvalue_get_action
icalvalue_get_attach
icalvalue_get_binary
icalvalue_get_boolean
icalvalue_get_caladdress
icalvalue_get_carlevel
icalvalue_get_class
icalvalue_get_cmd
icalvalue_get_date
icalvalue_get_datetime
icalvalue_get_datetimeperiod
icalvalue_get_duration
icalvalue_get_float
icalvalue_get_geo
icalvalue_get_integer
icalvalue_get_method
icalvalue_get_parent
icalvalue_get_period
icalvalue_get_query
icalvalue_get_querylevel
icalvalue_get_recur
icalvalue_get_requeststatus
icalvalue_get_status
icalvalue_get_string
icalvalue_get_text
icalvalue_get_transp
icalvalue_get_trigger
icalvalue_get_uri
icalvalue_get_utcoffset
icalvalue_get_x
icalvalue_get_xlicclass
icalvalue_is_valid
icalvalue_isa
icalvalue_isa_value
icalvalue_kind_is_valid
icalvalue_kind_to_string
icalvalue_new
icalvalue_new_action
icalvalue_new_attach
icalvalue_new_binary
icalvalue_new_boolean
icalvalue_new_caladdress
icalvalue_new_carlevel
icalvalue_new_class
icalvalue_new_clone
icalvalue_new_cmd
icalvalue_new_date
icalvalue_new_datetime
icalvalue_new_datetimeperiod
icalvalue_new_duration
icalvalue_new_float
icalvalue_new_from_string
icalvalue_new_from_string_with_error
icalvalue_new_geo
icalvalue_new_impl
icalvalue_new_integer
icalvalue_new_method
icalvalue_new_period
icalvalue_new_query
icalvalue_new_querylevel
icalvalue_new_recur
icalvalue_new_requeststatus
icalvalue_new_status
icalvalue_new_string
icalvalue_new_text
icalvalue_new_transp
icalvalue_new_trigger
icalvalue_new_uri
icalvalue_new_utcoffset
icalvalue_new_x
icalvalue_new_xlicclass
icalvalue_reset_kind
icalvalue_set_action
icalvalue_set_attach
icalvalue_set_binary
icalvalue_set_boolean
icalvalue_set_caladdress
icalvalue_set_carlevel
icalvalue_set_class
icalvalue_set_cmd
icalvalue_set_date
icalvalue_set_datetime
icalvalue_set_datetimeperiod
icalvalue_set_duration
icalvalue_set_float
icalvalue_set_geo
icalvalue_set_integer
icalvalue_set_method
icalvalue_set_parent
icalvalue_set_period
icalvalue_set_query
icalvalue_set_querylevel
icalvalue_set_recur
icalvalue_set_requeststatus
icalvalue_set_status
icalvalue_set_string
icalvalue_set_text
icalvalue_set_transp
icalvalue_set_trigger
icalvalue_set_uri
icalvalue_set_utcoffset
icalvalue_set_x
icalvalue_set_xlicclass
icalvalue_string_to_kind
juldat
null_comp_record DATA
null_prop_record DATA
print_date_to_string
print_datetime_to_string
print_time_to_string
pvl_apply
pvl_clear
pvl_count
pvl_data
pvl_elem_count DATA
pvl_find
pvl_find_next
pvl_free
pvl_head
pvl_insert_after
pvl_insert_before
pvl_insert_ordered
pvl_list_count DATA
pvl_new_element
pvl_newlist
pvl_next
pvl_pop
pvl_prior
pvl_push
pvl_remove
pvl_shift
pvl_tail
pvl_unshift
restr_string_map DATA
set_tz
set_zone_directory
sspm_action_map DATA
sspm_append_char
sspm_append_hex
sspm_append_string
sspm_build_header
sspm_default_add_line
sspm_default_end_part
sspm_default_free_part
sspm_default_new_part
sspm_encode_base64
sspm_encode_quoted_printable
sspm_encoding_map DATA
sspm_encoding_string
sspm_find_major_content_type
sspm_find_minor_content_type
sspm_free_header
sspm_free_parts
sspm_get_next_line
sspm_get_parameter
sspm_is_blank
sspm_is_continuation_line
sspm_is_mail_header
sspm_is_mime_boundary
sspm_is_mime_header
sspm_is_mime_terminating_boundary
sspm_lowercase
sspm_major_type_string
sspm_make_multipart_part
sspm_make_multipart_subpart
sspm_make_part
sspm_minor_type_string
sspm_parse_mime
sspm_property_name
sspm_read_header
sspm_set_error
sspm_store_part
sspm_strdup
sspm_value
sspm_write_base64
sspm_write_header
sspm_write_mime
sspm_write_multipart_part
sspm_write_part
strstriplt
unset_tz
ycaltime_days_in_year
