/* -*- Mode: C -*- */
/*======================================================================
 FILE: icalssutil.h
 CREATOR: eric 21 Aug 2000


 $Id: icalssutil.h,v 1.3 2008-01-02 20:15:45 dothebart Exp $
 $Locker:  $

 (C) COPYRIGHT 2000, Eric Busboom, http://www.softwarestudio.org

 This program is free software; you can redistribute it and/or modify
 it under the terms of either: 

    The LGPL as published by the Free Software Foundation, version
    2.1, available at: http://www.fsf.org/copyleft/lesser.html

  Or:

    The Mozilla Public License Version 1.0. You may obtain a copy of
    the License at http://www.mozilla.org/MPL/


 =========================================================================*/

#include <libical/ical.h>

